using System;
using Cpp2IlInjected;
using UnityEngine;

// Token: 0x02000346 RID: 838
[Token(Token = "0x2000346")]
[Serializable]
public class NobetaConfigData
{
	// Token: 0x17000181 RID: 385
	// (get) Token: 0x06001F42 RID: 8002 RVA: 0x0004AD88 File Offset: 0x00048F88
	[Token(Token = "0x17000181")]
	public int AirAttackIndex
	{
		[Token(Token = "0x6001F42")]
		[Address(RVA = "0x479280", Offset = "0x478280", VA = "0x180479280")]
		get
		{
			return this.airAttackIndex;
		}
	}

	// Token: 0x06001F43 RID: 8003 RVA: 0x0004AD9C File Offset: 0x00048F9C
	[Token(Token = "0x6001F43")]
	[Address(RVA = "0xF18C40", Offset = "0xF17C40", VA = "0x180F18C40")]
	public void InitMovementData(string path)
	{
		CSVData csvdata = new CSVData(path);
		int num = 0;
		float @float = csvdata.GetFloat(1, num);
		this.walkSpeed = @float;
		float float2 = csvdata.GetFloat(1, 1);
		this.runSpeed = float2;
		float float3 = csvdata.GetFloat(1, 2);
		this.dashSpeed = float3;
		float float4 = csvdata.GetFloat(1, 3);
		this.aimSpeed = float4;
		float float5 = csvdata.GetFloat(1, 4);
		this.shotSpeed = float5;
		float float6 = csvdata.GetFloat(1, 5);
		this.dodgeSpeedForward = float6;
		float float7 = csvdata.GetFloat(1, 6);
		this.dodgeSpeedBack = float7;
		int num2 = 0;
		float float8 = csvdata.GetFloat(3, num2);
		this.dashAttackSpeed = float8;
	}

	// Token: 0x06001F44 RID: 8004 RVA: 0x0004AE48 File Offset: 0x00049048
	[Token(Token = "0x6001F44")]
	[Address(RVA = "0xF18900", Offset = "0xF17900", VA = "0x180F18900")]
	public void InitAttackData(string path)
	{
		CSVData csvdata = new CSVData(path);
		int rowLength = csvdata.GetRowLength();
		this.attackDataLimit = rowLength;
		float[] allFloatValues = this.GetAllFloatValues(csvdata, "WaitTime");
		this.attackWaitTimes = allFloatValues;
		float[] allFloatValues2 = this.GetAllFloatValues(csvdata, "NextTime");
		this.attackNextTimes = allFloatValues2;
		float[] allFloatValues3 = this.GetAllFloatValues(csvdata, "NextEndTime");
		this.attackNextEndTimes = allFloatValues3;
		float[] allFloatValues4 = this.GetAllFloatValues(csvdata, "FreeTime");
		this.attackFreeTimes = allFloatValues4;
		float[] allFloatValues5 = this.GetAllFloatValues(csvdata, "DeltaTime");
		this.attackDeltaTimes = allFloatValues5;
		float[] allFloatValues6 = this.GetAllFloatValues(csvdata, "DeltaTime2");
		this.attackDelta2Times = allFloatValues6;
		float[] allFloatValues7 = this.GetAllFloatValues(csvdata, "MoveTime");
		this.attackMoveTimes = allFloatValues7;
		float[] allFloatValues8 = this.GetAllFloatValues(csvdata, "MoveTime2");
		this.attackMove2Times = allFloatValues8;
		float[] allFloatValues9 = this.GetAllFloatValues(csvdata, "MoveSpeed");
		this.attackMoveSpeed = allFloatValues9;
		float[] allFloatValues10 = this.GetAllFloatValues(csvdata, "MoveSpeed2");
		this.attackMoveSpeed2 = allFloatValues10;
		int rowLength2 = csvdata.GetRowLength();
		int[] array = new int[rowLength2];
		int num = 0;
		if (rowLength2 > 0)
		{
			int num2 = Animator.StringToHash(csvdata.GetString("AniName", num));
			num++;
			array[0] = num2;
		}
		this.attackAnimationHashes = array;
		throw new NullReferenceException();
	}

	// Token: 0x06001F45 RID: 8005 RVA: 0x0004AF8C File Offset: 0x0004918C
	[Token(Token = "0x6001F45")]
	[Address(RVA = "0xF18800", Offset = "0xF17800", VA = "0x180F18800")]
	public void InitAirAttackData(string path)
	{
		/*
An exception occurred when decompiling this method (06001F45)

ICSharpCode.Decompiler.DecompilerException: Error decompiling System.Void NobetaConfigData::InitAirAttackData(System.String)

 ---> System.Exception: Basic block has to end with unconditional control flow. 
{; 	Block_0:; 	stloc:CSVData(var_0_06, newobj:CSVData(CSVData::.ctor, ldloc:string(path))); 	stloc:float32[](var_1_13, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("WaitTime"))); 	stfld:float32[](NobetaConfigData::airAttackWaitTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_1_13)); 	stloc:float32[](var_2_27, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("NextTime"))); 	stfld:float32[](NobetaConfigData::airAttackNextTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_2_27)); 	stloc:float32[](var_3_3B, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("NextEndTime"))); 	stfld:float32[](NobetaConfigData::airAttackNextEndTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_3_3B)); }; 
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.FlattenBasicBlocks(ILNode node) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 1810
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.Optimize(DecompilerContext context, ILBlock method, AutoPropertyProvider autoPropertyProvider, StateMachineKind& stateMachineKind, MethodDef& inlinedMethod, AsyncMethodDebugInfo& asyncInfo, ILAstOptimizationStep abortBeforeStep) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 344
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(IEnumerable`1 parameters, MethodDebugInfoBuilder& builder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 123
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 88
   --- End of inner exception stack trace ---
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 92
   at ICSharpCode.Decompiler.Ast.AstBuilder.AddMethodBody(EntityDeclaration methodNode, EntityDeclaration& updatedNode, MethodDef method, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, MethodKind methodKind) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstBuilder.cs:line 1618
*/;
	}

	// Token: 0x06001F46 RID: 8006 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001F46")]
	[Address(RVA = "0xF183D0", Offset = "0xF173D0", VA = "0x180F183D0")]
	private float[] GetAllFloatValues(CSVData data, string propertyName)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001F47 RID: 8007 RVA: 0x0004AFDC File Offset: 0x000491DC
	[Token(Token = "0x6001F47")]
	[Address(RVA = "0xF18300", Offset = "0xF17300", VA = "0x180F18300")]
	private int[] GetAllAnimationHashes(CSVData data, string propertyName)
	{
		int rowLength = data.GetRowLength();
		int[] array = new int[rowLength];
		int num = 0;
		if (rowLength > 0)
		{
			int num2 = Animator.StringToHash(data.GetString(propertyName, num));
			num++;
			array[0] = num2;
		}
		return array;
	}

	// Token: 0x06001F48 RID: 8008 RVA: 0x0004B020 File Offset: 0x00049220
	[Token(Token = "0x6001F48")]
	[Address(RVA = "0x491570", Offset = "0x490570", VA = "0x180491570")]
	public float GetWalkSpeed()
	{
		return this.walkSpeed;
	}

	// Token: 0x06001F49 RID: 8009 RVA: 0x0004B034 File Offset: 0x00049234
	[Token(Token = "0x6001F49")]
	[Address(RVA = "0x56CCE0", Offset = "0x56BCE0", VA = "0x18056CCE0")]
	public float GetRunSpeed()
	{
		return this.runSpeed;
	}

	// Token: 0x06001F4A RID: 8010 RVA: 0x0004B048 File Offset: 0x00049248
	[Token(Token = "0x6001F4A")]
	[Address(RVA = "0x75AF40", Offset = "0x759F40", VA = "0x18075AF40")]
	public float GetDashSpeed()
	{
		return this.dashSpeed;
	}

	// Token: 0x06001F4B RID: 8011 RVA: 0x0004B05C File Offset: 0x0004925C
	[Token(Token = "0x6001F4B")]
	[Address(RVA = "0x5C7D20", Offset = "0x5C6D20", VA = "0x1805C7D20")]
	public float GetAimSpeed()
	{
		return this.aimSpeed;
	}

	// Token: 0x06001F4C RID: 8012 RVA: 0x0004B070 File Offset: 0x00049270
	[Token(Token = "0x6001F4C")]
	[Address(RVA = "0x41EBF0", Offset = "0x41DBF0", VA = "0x18041EBF0")]
	public float GetShotSpeed()
	{
		return this.shotSpeed;
	}

	// Token: 0x06001F4D RID: 8013 RVA: 0x0004B084 File Offset: 0x00049284
	[Token(Token = "0x6001F4D")]
	[Address(RVA = "0x5C2880", Offset = "0x5C1880", VA = "0x1805C2880")]
	public float GetDodgeSpeedF()
	{
		return this.dodgeSpeedForward;
	}

	// Token: 0x06001F4E RID: 8014 RVA: 0x0004B098 File Offset: 0x00049298
	[Token(Token = "0x6001F4E")]
	[Address(RVA = "0xB94720", Offset = "0xB93720", VA = "0x180B94720")]
	public float GetDodgeSpeedB()
	{
		return this.dodgeSpeedBack;
	}

	// Token: 0x06001F4F RID: 8015 RVA: 0x0004B0AC File Offset: 0x000492AC
	[Token(Token = "0x6001F4F")]
	[Address(RVA = "0x691E70", Offset = "0x690E70", VA = "0x180691E70")]
	public float GetDashAttackSpeed()
	{
		return this.dashAttackSpeed;
	}

	// Token: 0x06001F50 RID: 8016 RVA: 0x0004B0C0 File Offset: 0x000492C0
	[Token(Token = "0x6001F50")]
	[Address(RVA = "0x5A0D70", Offset = "0x59FD70", VA = "0x1805A0D70")]
	public void UpdateAttackIndex(int index)
	{
		this.attackIndex = index;
	}

	// Token: 0x06001F51 RID: 8017 RVA: 0x0004B0D4 File Offset: 0x000492D4
	[Token(Token = "0x6001F51")]
	[Address(RVA = "0xF187C0", Offset = "0xF177C0", VA = "0x180F187C0")]
	public float GetAttackWaitTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F52 RID: 8018 RVA: 0x0004B0FC File Offset: 0x000492FC
	[Token(Token = "0x6001F52")]
	[Address(RVA = "0xF18760", Offset = "0xF17760", VA = "0x180F18760")]
	public float GetAttackWaitTimeMinusNextTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackNextTimes;
		return num2;
	}

	// Token: 0x06001F53 RID: 8019 RVA: 0x0004B130 File Offset: 0x00049330
	[Token(Token = "0x6001F53")]
	[Address(RVA = "0xF18700", Offset = "0xF17700", VA = "0x180F18700")]
	public float GetAttackWaitTimeMinusFreeTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackFreeTimes;
		return num2;
	}

	// Token: 0x06001F54 RID: 8020 RVA: 0x0004B164 File Offset: 0x00049364
	[Token(Token = "0x6001F54")]
	[Address(RVA = "0xF186A0", Offset = "0xF176A0", VA = "0x180F186A0")]
	public float GetAttackWaitTimeMinusDelta2Time()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackDelta2Times;
		return num2;
	}

	// Token: 0x06001F55 RID: 8021 RVA: 0x0004B198 File Offset: 0x00049398
	[Token(Token = "0x6001F55")]
	[Address(RVA = "0xF18660", Offset = "0xF17660", VA = "0x180F18660")]
	public float GetAttackNextEndTime()
	{
		float[] array = this.attackNextEndTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F56 RID: 8022 RVA: 0x0004B1C0 File Offset: 0x000493C0
	[Token(Token = "0x6001F56")]
	[Address(RVA = "0xF18520", Offset = "0xF17520", VA = "0x180F18520")]
	public float GetAttackDeltaTime()
	{
		float[] array = this.attackDeltaTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F57 RID: 8023 RVA: 0x0004B1E8 File Offset: 0x000493E8
	[Token(Token = "0x6001F57")]
	[Address(RVA = "0xF184E0", Offset = "0xF174E0", VA = "0x180F184E0")]
	public float GetAttackDelta2Time()
	{
		float[] array = this.attackDelta2Times;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F58 RID: 8024 RVA: 0x0004B210 File Offset: 0x00049410
	[Token(Token = "0x6001F58")]
	[Address(RVA = "0xF18620", Offset = "0xF17620", VA = "0x180F18620")]
	public float GetAttackMoveTime()
	{
		float[] array = this.attackMoveTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F59 RID: 8025 RVA: 0x0004B238 File Offset: 0x00049438
	[Token(Token = "0x6001F59")]
	[Address(RVA = "0xF18560", Offset = "0xF17560", VA = "0x180F18560")]
	public float GetAttackMove2Time()
	{
		float[] array = this.attackMove2Times;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F5A RID: 8026 RVA: 0x0004B260 File Offset: 0x00049460
	[Token(Token = "0x6001F5A")]
	[Address(RVA = "0xF185E0", Offset = "0xF175E0", VA = "0x180F185E0")]
	public float GetAttackMoveSpeed()
	{
		float[] array = this.attackMoveSpeed;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F5B RID: 8027 RVA: 0x0004B288 File Offset: 0x00049488
	[Token(Token = "0x6001F5B")]
	[Address(RVA = "0xF185A0", Offset = "0xF175A0", VA = "0x180F185A0")]
	public float GetAttackMoveSpeed2()
	{
		float[] array = this.attackMoveSpeed2;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F5C RID: 8028 RVA: 0x0004B2B0 File Offset: 0x000494B0
	[Token(Token = "0x6001F5C")]
	[Address(RVA = "0xF184A0", Offset = "0xF174A0", VA = "0x180F184A0")]
	public int GetAttackAnimationHash()
	{
		int[] array = this.attackAnimationHashes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001F5D RID: 8029 RVA: 0x0004B2D8 File Offset: 0x000494D8
	[Token(Token = "0x6001F5D")]
	[Address(RVA = "0xF18C30", Offset = "0xF17C30", VA = "0x180F18C30")]
	public void InitAttackIndex()
	{
		if (this.attackIndex < 1)
		{
			this.attackIndex = (int)((ulong)1L);
		}
	}

	// Token: 0x06001F5E RID: 8030 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001F5E")]
	[Address(RVA = "0xF18D70", Offset = "0xF17D70", VA = "0x180F18D70")]
	public bool TryIncreaseAttackIndex()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001F5F RID: 8031 RVA: 0x0004B2F8 File Offset: 0x000494F8
	[Token(Token = "0x6001F5F")]
	[Address(RVA = "0x479460", Offset = "0x478460", VA = "0x180479460")]
	public void UpdateAirAttackIndex(int index)
	{
		this.airAttackIndex = index;
	}

	// Token: 0x06001F60 RID: 8032 RVA: 0x0004B30C File Offset: 0x0004950C
	[Token(Token = "0x6001F60")]
	[Address(RVA = "0xF182C0", Offset = "0xF172C0", VA = "0x180F182C0")]
	public float GetAirAttackWaitTime()
	{
		float[] array = this.airAttackWaitTimes;
		int num = this.airAttackIndex;
		return array[num];
	}

	// Token: 0x06001F61 RID: 8033 RVA: 0x0004B334 File Offset: 0x00049534
	[Token(Token = "0x6001F61")]
	[Address(RVA = "0xF18250", Offset = "0xF17250", VA = "0x180F18250")]
	public float GetAirAttackWaitTimeMinusNextTime()
	{
		float[] array = this.airAttackWaitTimes;
		int num = this.airAttackIndex;
		float num2 = array[num];
		float[] array2 = this.airAttackNextTimes;
		return num2;
	}

	// Token: 0x06001F62 RID: 8034 RVA: 0x0004B368 File Offset: 0x00049568
	[Token(Token = "0x6001F62")]
	[Address(RVA = "0xF18210", Offset = "0xF17210", VA = "0x180F18210")]
	public float GetAirAttackNextEndTime()
	{
		float[] array = this.airAttackNextEndTimes;
		int num = this.airAttackIndex;
		return array[num];
	}

	// Token: 0x06001F63 RID: 8035 RVA: 0x0004B390 File Offset: 0x00049590
	[Token(Token = "0x6001F63")]
	[Address(RVA = "0x36ABD0", Offset = "0x369BD0", VA = "0x18036ABD0")]
	public NobetaConfigData()
	{
	}

	// Token: 0x0400287E RID: 10366
	[FieldOffset(Offset = "0x10")]
	[Token(Token = "0x400287E")]
	[SerializeField]
	private float walkSpeed;

	// Token: 0x0400287F RID: 10367
	[FieldOffset(Offset = "0x14")]
	[Token(Token = "0x400287F")]
	[SerializeField]
	private float runSpeed;

	// Token: 0x04002880 RID: 10368
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x4002880")]
	[SerializeField]
	private float dashSpeed;

	// Token: 0x04002881 RID: 10369
	[FieldOffset(Offset = "0x1C")]
	[Token(Token = "0x4002881")]
	[SerializeField]
	private float aimSpeed;

	// Token: 0x04002882 RID: 10370
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x4002882")]
	[SerializeField]
	private float shotSpeed;

	// Token: 0x04002883 RID: 10371
	[FieldOffset(Offset = "0x24")]
	[Token(Token = "0x4002883")]
	[SerializeField]
	private float dodgeSpeedForward;

	// Token: 0x04002884 RID: 10372
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x4002884")]
	[SerializeField]
	private float dodgeSpeedBack;

	// Token: 0x04002885 RID: 10373
	[FieldOffset(Offset = "0x2C")]
	[Token(Token = "0x4002885")]
	[SerializeField]
	private float dashAttackSpeed;

	// Token: 0x04002886 RID: 10374
	[FieldOffset(Offset = "0x30")]
	[Token(Token = "0x4002886")]
	[SerializeField]
	private int attackIndex;

	// Token: 0x04002887 RID: 10375
	[FieldOffset(Offset = "0x34")]
	[Token(Token = "0x4002887")]
	[SerializeField]
	private int attackDataLimit;

	// Token: 0x04002888 RID: 10376
	[FieldOffset(Offset = "0x38")]
	[Token(Token = "0x4002888")]
	[SerializeField]
	private float[] attackWaitTimes;

	// Token: 0x04002889 RID: 10377
	[FieldOffset(Offset = "0x40")]
	[Token(Token = "0x4002889")]
	[SerializeField]
	private float[] attackNextTimes;

	// Token: 0x0400288A RID: 10378
	[FieldOffset(Offset = "0x48")]
	[Token(Token = "0x400288A")]
	[SerializeField]
	private float[] attackNextEndTimes;

	// Token: 0x0400288B RID: 10379
	[FieldOffset(Offset = "0x50")]
	[Token(Token = "0x400288B")]
	[SerializeField]
	private float[] attackFreeTimes;

	// Token: 0x0400288C RID: 10380
	[FieldOffset(Offset = "0x58")]
	[Token(Token = "0x400288C")]
	[SerializeField]
	private float[] attackDeltaTimes;

	// Token: 0x0400288D RID: 10381
	[FieldOffset(Offset = "0x60")]
	[Token(Token = "0x400288D")]
	[SerializeField]
	private float[] attackDelta2Times;

	// Token: 0x0400288E RID: 10382
	[FieldOffset(Offset = "0x68")]
	[Token(Token = "0x400288E")]
	[SerializeField]
	private float[] attackMoveTimes;

	// Token: 0x0400288F RID: 10383
	[FieldOffset(Offset = "0x70")]
	[Token(Token = "0x400288F")]
	[SerializeField]
	private float[] attackMove2Times;

	// Token: 0x04002890 RID: 10384
	[FieldOffset(Offset = "0x78")]
	[Token(Token = "0x4002890")]
	[SerializeField]
	private float[] attackMoveSpeed;

	// Token: 0x04002891 RID: 10385
	[FieldOffset(Offset = "0x80")]
	[Token(Token = "0x4002891")]
	[SerializeField]
	private float[] attackMoveSpeed2;

	// Token: 0x04002892 RID: 10386
	[FieldOffset(Offset = "0x88")]
	[Token(Token = "0x4002892")]
	[SerializeField]
	private int[] attackAnimationHashes;

	// Token: 0x04002893 RID: 10387
	[FieldOffset(Offset = "0x90")]
	[Token(Token = "0x4002893")]
	[SerializeField]
	private int airAttackIndex;

	// Token: 0x04002894 RID: 10388
	[FieldOffset(Offset = "0x98")]
	[Token(Token = "0x4002894")]
	[SerializeField]
	private float[] airAttackWaitTimes;

	// Token: 0x04002895 RID: 10389
	[FieldOffset(Offset = "0xA0")]
	[Token(Token = "0x4002895")]
	[SerializeField]
	private float[] airAttackNextTimes;

	// Token: 0x04002896 RID: 10390
	[FieldOffset(Offset = "0xA8")]
	[Token(Token = "0x4002896")]
	[SerializeField]
	private float[] airAttackNextEndTimes;
}
